"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeProvider = exports.WSTreeItem = exports.createNode = exports.getAncestryTextOffsets = exports.getAncestryTextArray = exports.getAncestry = void 0;
const vscode = require("vscode");
function getAncestry(nodeId, tree) {
    let ancestry = [nodeId];
    let node = tree[nodeId];
    while (node.parentId) {
        ancestry.push(node.parentId);
        node = tree[node.parentId];
    }
    // reverse array
    ancestry.reverse();
    return ancestry;
}
exports.getAncestry = getAncestry;
function getAncestryTextArray(nodeId, tree) {
    const ancestry = getAncestry(nodeId, tree);
    let ancestryText = [];
    for (let i = ancestry.length - 1; i >= 0; i--) {
        ancestryText.push(tree[ancestry[i]].text);
    }
    return ancestryText;
}
exports.getAncestryTextArray = getAncestryTextArray;
function getAncestryTextOffsets(nodeId, tree) {
    const ancestry = getAncestry(nodeId, tree);
    let ancestryTextOffsets = {};
    let offset = 0;
    for (let i = ancestry.length - 1; i >= 0; i--) {
        ancestryTextOffsets[ancestry[i]] = offset;
        offset += tree[ancestry[i]].text.length;
    }
    return ancestryTextOffsets;
}
exports.getAncestryTextOffsets = getAncestryTextOffsets;
function createNode(parentId, text, tree) {
    const nodeId = Math.random().toString(36).substring(7);
    tree[nodeId] = {
        parentId,
        text,
        childrenIds: [],
    };
    if (parentId) {
        tree[parentId].childrenIds.push(nodeId);
    }
    return nodeId;
}
exports.createNode = createNode;
class WSTreeItem extends vscode.TreeItem {
    constructor(id, label, collapsibleState, command, contextValue = 'treeItem') {
        super(label, collapsibleState);
        this.id = id;
        this.label = label;
        this.collapsibleState = collapsibleState;
        this.command = command;
        this.contextValue = contextValue;
    }
}
exports.WSTreeItem = WSTreeItem;
class NodeProvider {
    constructor(tree) {
        this.tree = tree;
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
    }
    refresh() {
        this._onDidChangeTreeData.fire();
    }
    getTreeItem(element) {
        return element;
    }
    getTreeItemById(id) {
        return new WSTreeItem(id, this.tree[id].text, vscode.TreeItemCollapsibleState.Collapsed);
    }
    getChildren(element) {
        if (!element) {
            // get root nodes
            const rootNodes = Object.keys(this.tree).filter((nodeId) => {
                return this.tree[nodeId].parentId === null;
            });
            return Promise.resolve(rootNodes.map((nodeId) => {
                return new WSTreeItem(nodeId, this.tree[nodeId].text, vscode.TreeItemCollapsibleState.Collapsed);
            }));
        }
        else {
            // get children of element
            const children = this.tree[element.id].childrenIds;
            return Promise.resolve(children.map((nodeId) => {
                return new WSTreeItem(nodeId, this.tree[nodeId].text, vscode.TreeItemCollapsibleState.Collapsed);
            }));
        }
    }
}
exports.NodeProvider = NodeProvider;
//# sourceMappingURL=tree.js.map